# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import typing_extensions

from .jpeg import Jpeg
from .png import Png


class HealthInsuranceCreateRequestPatientSignatureImage_ImageJpeg(Jpeg):
    content_type: typing_extensions.Literal["image/jpeg"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class HealthInsuranceCreateRequestPatientSignatureImage_ImagePng(Png):
    content_type: typing_extensions.Literal["image/png"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


HealthInsuranceCreateRequestPatientSignatureImage = typing.Union[
    HealthInsuranceCreateRequestPatientSignatureImage_ImageJpeg,
    HealthInsuranceCreateRequestPatientSignatureImage_ImagePng,
]
