# This file was auto-generated by Fern from our API Definition.

import typing

from .user_sign_in_token import UserSignInToken

UserSignInTokenResponseSignInToken = typing.Union[UserSignInToken, str]
